@@ -4,6 +4,7 @@ import itertools
 
 from clint import args
 import sunlight
+from sunlight.service import EntityList, EntityDict
 
 
 def main():
@@ -23,6 +24,8 @@ def main():
             fn_args = [g.split(',') for g in args.grouped.get('_')[2:]]
             fn_args = list(itertools.chain.from_iterable(fn_args))
             resp = getattr(service, args.get(1))(*fn_args, **params)
+            if isinstance(resp, EntityList) or isinstance(resp, EntityDict):
+                resp = resp.data
             sys.stdout.write(json.dumps(resp, indent=2) + '\n')
 
         else:
